/*  log.c  --  Error and warning messages.
 *
 * Copyright (C) 2016 Tomasz Kramkowski <tk@the-tk.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#include <assert.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "log.h"

const char *argv0;

void error(int errnum, const char *fmt, ...)
{
	assert(fmt);

	va_list va;

	fprintf(stderr, "%s: error: ", argv0);

	va_start(va, fmt);
	vfprintf(stderr, fmt, va);
	va_end(va);

	if (errnum)
		fprintf(stderr, ": %s", strerror(errnum));

	fputc('\n', stderr);

	exit(EXIT_FAILURE);
}

void errorat(int errnum, const char *file, long line, const char *fmt, ...)
{
	assert(file && fmt);

	va_list va;

	fprintf(stderr, "%s:%s:%ld: error: ", argv0, file, line);

	va_start(va, fmt);
	vfprintf(stderr, fmt, va);
	va_end(va);

	if (errnum)
		fprintf(stderr, ": %s", strerror(errnum));

	fputc('\n', stderr);

	exit(EXIT_FAILURE);
}

void warning(int errnum, const char *fmt, ...)
{
	va_list ap;

	fprintf(stderr, "%s: warning: ", argv0);

	va_start(ap, fmt);
	vfprintf(stderr, fmt, ap);
	va_end(ap);

	if (errnum)
		fprintf(stderr, ": %s", strerror(errnum));

	fputc('\n', stderr);
}

void warningat(int errnum, const char *file, long line, const char *fmt, ...)
{
	va_list ap;

	fprintf(stderr, "%s:%s:%ld: warning: ", argv0, file, line);

	va_start(ap, fmt);
	vfprintf(stderr, fmt, ap);
	va_end(ap);

	if (errnum)
		fprintf(stderr, ": %s", strerror(errnum));

	fputc('\n', stderr);
}
